static const struct { const char *name; const wchar_t *builtin; int type; guchar width; guchar height; guchar hotx; guchar hoty; char *data; } cursors[] = {
  { "X_cursor", NULL, 0, 16, 16, 7, 7, 
    "\125\000\000\125\152\100\001\251\152\220\006\251\152\244\032\251"
    "\032\251\152\244\006\252\252\220\001\252\252\100\000\152\251\000"
    "\000\152\251\000\001\252\252\100\006\252\252\220\032\251\152\244"
    "\152\244\032\251\152\220\006\251\152\100\001\251\125\000\000\125" }, 
  { "arrow", IDC_ARROW, 2, 16, 16, 14, 1, 
    "\000\000\000\025\000\000\001\151\000\000\026\251\000\001\152\244"
    "\000\026\252\244\001\152\252\220\006\252\252\220\005\126\252\100"
    "\000\032\252\100\000\152\151\000\001\251\151\000\006\244\144\000"
    "\032\220\144\000\152\100\020\000\031\000\000\000\004\000\000\000" }, 
  { "based_arrow_down", NULL, 4, 10, 12, 4, 10, 
    "\125\125\126\252\251\125\125\126\252\251\125\245\120\032\100\001"
    "\244\001\132\124\031\246\101\152\224\005\245\000\025\100" }, 
  { "based_arrow_up", NULL, 6, 10, 12, 4, 10, 
    "\000\120\000\032\100\026\251\101\232\144\025\245\100\032\100\001"
    "\244\005\132\125\152\252\225\125\125\152\252\225\125\125" }, 
  { "boat", NULL, 8, 16, 9, 14, 4, 
    "\000\026\000\000\000\152\240\000\201\225\150\000\252\252\252\252"
    "\125\125\126\225\125\125\131\125\125\125\145\100\252\252\244\000"
    "\125\125\120\000" }, 
  { "bogosity", NULL, 10, 15, 16, 7, 7, 
    "\125\105\105\125\251\031\032\225\144\144\145\101\221\221\220\126"
    "\126\126\125\252\252\252\226\145\145\146\131\221\221\231\146\106"
    "\106\145\231\131\131\226\252\252\252\125\225\225\225\006\106\106"
    "\101\131\031\031\126\244\144\152\125\121\121\125" }, 
  { "bottom_left_corner", IDC_SIZENESW, 12, 16, 16, 1, 14, 
    "\125\000\000\000\151\000\000\000\151\025\000\120\151\031\001\220"
    "\151\031\006\100\151\031\031\000\151\031\144\000\151\031\220\000"
    "\151\032\125\120\151\032\252\220\151\025\125\120\151\000\000\000"
    "\151\125\125\125\152\252\252\251\152\252\252\251\125\125\125\125" }, 
  { "bottom_right_corner", IDC_SIZENWSE, 14, 16, 16, 14, 14, 
    "\000\000\000\125\000\000\000\151\005\000\124\151\006\100\144\151"
    "\001\220\144\151\000\144\144\151\000\031\144\151\000\006\144\151"
    "\005\125\244\151\006\252\244\151\005\125\124\151\000\000\000\151"
    "\125\125\125\151\152\252\252\251\152\252\252\251\125\125\125\125" }, 
  { "bottom_side", IDC_SIZENS, 16, 15, 16, 7, 14, 
    "\000\005\100\000\000\031\000\000\000\144\000\000\001\220\000\000"
    "\006\100\000\000\031\000\000\120\144\024\001\221\221\220\001\226"
    "\131\000\001\231\220\000\001\251\000\000\001\220\000\125\125\125"
    "\125\252\252\252\226\252\252\252\125\125\125\125" }, 
  { "bottom_tee", NULL, 18, 16, 12, 8, 10, 
    "\000\005\120\000\000\006\220\000\000\006\220\000\000\006\220\000"
    "\000\006\220\000\000\006\220\000\000\006\220\000\000\006\220\000"
    "\125\126\225\125\152\252\252\251\152\252\252\251\125\125\125\125" }, 
  { "box_spiral", NULL, 20, 16, 16, 8, 8, 
    "\252\252\252\251\225\125\125\125\232\252\252\251\231\125\125\131"
    "\231\252\252\231\231\225\125\231\231\232\251\231\231\231\131\231"
    "\231\231\231\231\231\232\231\231\231\225\131\231\231\252\251\231"
    "\231\125\125\231\232\252\252\231\225\125\125\131\252\252\252\251" }, 
  { "center_ptr", IDC_UPARROW, 22, 12, 16, 5, 1, 
    "\000\125\000\000\151\000\001\151\100\001\252\100\005\252\120\006"
    "\252\220\026\252\224\032\252\244\132\252\245\151\151\151\145\151"
    "\131\124\151\025\000\151\000\000\151\000\000\151\000\000\125\000" }, 
  { "circle", NULL, 24, 16, 16, 8, 8, 
    "\000\025\124\000\001\132\245\100\005\252\252\120\026\252\252\224"
    "\032\245\132\244\132\220\006\245\152\100\001\251\152\100\001\251"
    "\152\100\001\251\152\100\001\251\132\220\006\245\032\245\132\244"
    "\026\252\252\224\005\252\252\120\001\132\245\100\000\025\124\000" }, 
  { "clock", IDC_APPSTARTING, 26, 15, 16, 6, 3, 
    "\032\252\252\101\241\252\012\112\030\132\112\141\206\222\111\206"
    "\251\131\046\006\124\220\232\006\251\012\132\252\252\244\142\032"
    "\110\221\210\151\042\106\041\244\211\030\232\246\044\242\032\110"
    "\246\250\024\052\232\252\252\252\152\252\252\251" }, 
  { "coffee_mug", NULL, 28, 16, 16, 7, 9, 
    "\002\252\252\000\011\125\125\200\051\125\125\151\046\125\126\231"
    "\145\252\251\131\245\125\125\131\245\125\125\131\145\125\125\131"
    "\045\125\125\131\046\226\126\231\151\231\231\231\251\232\231\231"
    "\246\231\226\231\145\125\125\131\045\125\125\131\012\252\252\240" }, 
  { "cross", IDC_CROSS, 30, 16, 15, 7, 7, 
    "\000\031\220\000\000\031\220\000\000\031\220\000\000\031\220\000"
    "\000\031\220\000\125\131\225\125\252\251\252\252\125\125\125\125"
    "\252\251\252\252\125\131\225\125\000\031\220\000\000\031\220\000"
    "\000\031\220\000\000\031\220\000\000\031\220\000" }, 
  { "cross_reverse", NULL, 32, 16, 15, 7, 7, 
    "\044\030\220\140\211\030\221\211\142\130\226\044\030\230\230\220"
    "\006\050\242\100\125\210\211\125\252\240\052\252\000\001\000\000"
    "\252\240\052\252\125\210\211\125\006\050\242\100\030\230\230\220"
    "\142\130\226\044\211\030\221\211\044\030\220\140" }, 
  { "crosshair", IDC_CROSS, 34, 16, 15, 7, 7, 
    "\000\006\100\000\000\006\100\000\000\006\100\000\000\006\100\000"
    "\000\006\100\000\000\006\100\000\125\126\125\125\252\251\252\252"
    "\125\126\125\125\000\006\100\000\000\006\100\000\000\006\100\000"
    "\000\006\100\000\000\006\100\000\000\006\100\000" }, 
  { "diamond_cross", NULL, 36, 15, 15, 7, 7, 
    "\000\031\220\000\001\246\220\000\031\231\220\001\222\141\220\031"
    "\011\201\221\220\046\001\232\252\232\252\225\125\025\125\252\251"
    "\252\251\220\046\001\221\220\230\031\001\222\141\220\001\231\231"
    "\000\001\246\220\000\001\231\000\000" }, 
  { "dot", NULL, 38, 12, 12, 6, 6, 
    "\001\125\100\025\252\124\032\252\244\132\252\245\152\252\251\152"
    "\252\251\152\252\251\152\252\251\132\252\245\032\252\244\025\252"
    "\124\001\125\100" }, 
  { "dotbox", NULL, 40, 14, 14, 7, 6, 
    "\125\125\125\126\252\252\251\145\125\125\226\100\000\031\144\000"
    "\001\226\101\124\031\144\032\101\226\101\244\031\144\025\101\226"
    "\100\000\031\144\000\001\226\125\125\131\152\252\252\225\125\125"
    "\125" }, 
  { "double_arrow", IDC_SIZENS, 42, 12, 16, 6, 8, 
    "\000\125\000\001\151\100\005\252\120\026\252\224\132\151\245\151"
    "\151\151\125\151\125\000\151\000\000\151\000\125\151\125\151\151"
    "\151\132\151\245\026\252\224\005\252\120\001\151\100\000\125\000" }, 
  { "draft_large", NULL, 44, 15, 15, 14, 0, 
    "\000\000\000\030\000\000\006\220\000\001\252\100\000\152\244\000"
    "\032\252\200\006\252\251\001\252\252\240\005\125\252\100\000\031"
    "\250\000\001\226\220\000\031\032\000\001\220\144\000\031\001\200"
    "\001\220\005\000\011\000\000\000\000" }, 
  { "draft_small", NULL, 46, 15, 15, 14, 0, 
    "\000\000\000\030\000\000\006\220\000\001\252\000\000\152\244\000"
    "\032\252\200\000\125\251\000\000\031\240\000\001\226\100\000\031"
    "\030\000\001\220\100\000\031\000\000\001\220\000\000\031\000\000"
    "\001\220\000\000\011\000\000\000\000" }, 
  { "draped_box", NULL, 48, 14, 14, 7, 6, 
    "\125\125\125\126\252\252\251\140\145\220\226\032\132\111\146\220"
    "\151\226\244\121\251\145\032\105\226\121\244\131\152\105\032\226"
    "\151\006\231\141\245\244\226\006\131\011\152\252\252\225\125\125"
    "\125" }, 
  { "exchange", NULL, 50, 16, 16, 7, 7, 
    "\120\025\124\000\144\152\251\000\151\252\252\100\152\245\126\220"
    "\145\220\001\220\145\245\000\120\152\251\000\000\125\125\000\000"
    "\000\000\125\125\000\000\152\251\005\000\032\131\006\100\006\131"
    "\006\225\132\251\001\252\252\151\000\152\251\031\000\025\124\005" }, 
  { "fleur", IDC_SIZEALL, 52, 16, 16, 8, 8, 
    "\000\005\120\000\000\006\224\000\000\032\244\000\000\152\251\000"
    "\001\026\224\100\006\106\221\220\132\126\225\245\152\252\252\251"
    "\152\252\252\251\132\126\225\245\006\106\221\220\001\026\224\100"
    "\000\152\251\000\000\032\244\000\000\006\220\000\000\005\120\000" }, 
  { "gobbler", NULL, 54, 16, 16, 14, 2, 
    "\000\000\125\120\000\000\152\220\120\000\152\125\225\125\132\132"
    "\226\252\232\125\252\252\252\120\252\251\132\120\252\245\132\120"
    "\151\125\132\220\125\125\252\120\026\252\251\100\001\225\125\000"
    "\001\220\000\000\001\220\000\000\005\225\000\000\006\251\000\000" }, 
  { "gumby", NULL, 56, 16, 16, 2, 0, 
    "\012\252\000\000\122\125\200\000\244\225\140\000\251\231\230\000"
    "\244\225\130\000\244\232\231\120\252\225\132\244\132\225\132\252"
    "\005\225\130\152\000\225\130\152\000\226\131\252\000\226\130\152"
    "\000\226\130\025\002\126\126\000\011\126\125\200\012\250\252\200" }, 
  { "hand1", IDC_HAND, 58, 13, 16, 12, 0, 
    "\000\000\006\200\000\032\240\000\152\220\000\152\220\000\152\220"
    "\000\152\251\001\152\252\221\232\252\224\252\252\251\046\252\252"
    "\105\132\252\101\126\252\100\226\145\100\051\131\000\006\231\000"
    "\000\151\000\000" }, 
  { "hand2", IDC_HAND, 60, 16, 16, 0, 1, 
    "\025\125\100\000\152\252\220\000\225\125\144\000\152\251\131\000"
    "\026\125\126\100\001\251\126\100\006\125\126\100\001\251\131\220"
    "\006\125\145\144\001\245\225\131\000\132\125\144\000\031\145\220"
    "\000\006\126\100\000\001\231\000\000\000\144\000\000\000\020\000" }, 
  { "heart", NULL, 62, 15, 14, 6, 8, 
    "\012\250\252\200\245\152\126\212\100\144\006\244\000\100\006\220"
    "\000\000\032\100\000\000\151\000\104\001\251\000\100\032\051\000"
    "\001\240\051\000\032\000\051\001\240\000\051\132\000\000\051\240"
    "\000\000\052\000\000" }, 
  { "icon", NULL, 64, 16, 16, 8, 8, 
    "\252\252\252\252\246\146\146\146\231\231\231\232\246\146\146\146"
    "\231\125\125\232\246\125\125\146\231\125\125\232\246\125\125\146"
    "\231\125\125\232\246\125\125\146\231\125\125\232\246\125\125\146"
    "\231\231\231\232\246\146\146\146\231\231\231\232\252\252\252\252" }, 
  { "iron_cross", NULL, 66, 16, 16, 8, 7, 
    "\005\125\125\120\032\252\252\244\026\252\252\224\145\252\252\131"
    "\151\152\251\151\152\132\245\251\152\226\226\251\152\252\252\251"
    "\152\252\252\251\152\226\226\251\152\132\245\251\151\152\251\151"
    "\145\252\252\131\026\252\252\224\032\252\252\244\005\125\125\120" }, 
  { "left_ptr", IDC_ARROW, 68, 10, 16, 1, 1, 
    "\120\000\006\100\000\151\000\006\244\000\152\220\006\252\100\152"
    "\251\006\252\244\152\252\226\252\125\151\244\006\106\220\120\151"
    "\000\001\244\000\032\100\000\120" }, 
  { "left_side", IDC_SIZEWE, 70, 16, 15, 1, 7, 
    "\125\000\000\000\151\000\000\000\151\000\120\000\151\001\220\000"
    "\151\006\100\000\151\031\000\000\151\145\125\125\151\252\252\251"
    "\151\145\125\125\151\031\000\000\151\006\100\000\151\001\220\000"
    "\151\000\120\000\151\000\000\000\125\000\000\000" }, 
  { "left_tee", NULL, 72, 12, 16, 1, 8, 
    "\125\000\000\151\000\000\151\000\000\151\000\000\151\000\000\151"
    "\000\000\151\125\125\152\252\251\152\252\251\151\125\125\151\000"
    "\000\151\000\000\151\000\000\151\000\000\151\000\000\125\000\000" }, 
  { "leftbutton", NULL, 74, 16, 16, 8, 8, 
    "\025\125\125\120\152\252\252\244\152\252\252\244\145\145\145\144"
    "\145\146\146\144\145\146\146\144\145\146\146\144\145\146\146\144"
    "\145\145\145\144\152\252\252\244\152\252\252\244\152\252\252\244"
    "\152\252\252\244\152\252\252\244\152\252\252\244\025\125\125\120" }, 
  { "ll_angle", NULL, 76, 12, 12, 1, 10, 
    "\125\000\000\151\000\000\151\000\000\151\000\000\151\000\000\151"
    "\000\000\151\000\000\151\000\000\151\125\125\152\252\251\152\252"
    "\251\125\125\125" }, 
  { "lr_angle", NULL, 78, 12, 12, 10, 10, 
    "\000\000\125\000\000\151\000\000\151\000\000\151\000\000\151\000"
    "\000\151\000\000\151\000\000\151\125\125\151\152\252\251\152\252"
    "\251\125\125\125" }, 
  { "man", NULL, 80, 16, 16, 14, 5, 
    "\001\132\224\000\006\251\252\000\005\131\225\100\220\006\100\004"
    "\144\032\220\052\031\145\145\232\006\246\152\105\001\146\145\000"
    "\000\045\144\000\000\031\220\000\000\145\144\000\001\226\131\000"
    "\006\131\226\100\026\144\146\120\152\220\032\245\252\220\032\252" }, 
  { "middlebutton", NULL, 82, 16, 16, 8, 8, 
    "\025\125\125\120\152\252\252\244\152\252\252\244\145\145\145\144"
    "\146\145\146\144\146\145\146\144\146\145\146\144\146\145\146\144"
    "\145\145\145\144\152\252\252\244\152\252\252\244\152\252\252\244"
    "\152\252\252\244\152\252\252\244\152\252\252\244\025\125\125\120" }, 
  { "mouse", NULL, 84, 16, 16, 4, 1, 
    "\000\125\100\000\001\124\000\000\000\152\000\000\000\045\000\000"
    "\025\151\125\100\125\132\125\120\152\252\252\225\225\125\125\145"
    "\232\132\132\151\232\132\132\151\232\132\132\151\225\125\125\151"
    "\005\125\125\051\001\125\124\000\000\225\140\000\000\052\200\000" }, 
  { "pencil", NULL, 86, 13, 16, 11, 15, 
    "\132\220\000\031\131\000\006\126\220\000\145\230\000\012\246\100"
    "\001\225\140\000\031\131\000\002\125\200\000\145\144\000\012\126"
    "\000\001\225\220\000\031\131\000\001\252\100\000\032\220\000\001"
    "\244\000\000\031" }, 
  { "pirate", IDC_NO, 88, 16, 16, 7, 12, 
    "\000\152\220\000\001\252\244\000\006\252\251\000\032\132\132\100"
    "\032\132\132\100\006\252\251\000\001\252\244\000\100\152\220\001"
    "\200\152\220\045\220\152\220\151\145\032\101\220\032\200\052\100"
    "\000\052\200\000\026\252\250\011\252\125\132\251\225\000\005\144" }, 
  { "plus", NULL, 90, 12, 12, 5, 6, 
    "\000\125\000\000\151\000\000\151\000\000\151\000\125\151\125\152"
    "\252\251\152\252\251\125\151\125\000\151\000\000\151\000\000\151"
    "\000\000\125\000" }, 
  { "question_arrow", IDC_HELP, 92, 11, 16, 5, 8, 
    "\002\252\000\052\252\002\245\152\032\125\151\152\001\245\151\012"
    "\221\124\251\101\152\224\001\251\100\006\144\000\031\220\002\246"
    "\240\026\232\120\026\245\000\026\120\000\025\000" }, 
  { "right_ptr", NULL, 94, 10, 16, 8, 1, 
    "\000\000\120\000\031\000\006\220\001\251\000\152\220\032\251\006"
    "\252\221\252\251\152\252\225\132\251\001\246\220\151\031\006\220"
    "\121\244\000\032\100\000\120\000" }, 
  { "right_side", IDC_SIZEWE, 96, 16, 15, 14, 7, 
    "\000\000\000\125\000\000\000\151\000\005\000\151\000\006\100\151"
    "\000\001\220\151\000\000\144\151\125\125\131\151\152\252\252\151"
    "\125\125\131\151\000\000\144\151\000\001\220\151\000\006\100\151"
    "\000\005\000\151\000\000\000\151\000\000\000\125" }, 
  { "right_tee", NULL, 98, 12, 16, 10, 8, 
    "\000\000\125\000\000\151\000\000\151\000\000\151\000\000\151\000"
    "\000\151\125\125\151\152\252\251\152\252\251\125\125\151\000\000"
    "\151\000\000\151\000\000\151\000\000\151\000\000\151\000\000\125" }, 
  { "rightbutton", NULL, 100, 16, 16, 8, 8, 
    "\025\125\125\120\152\252\252\244\152\252\252\244\145\145\145\144"
    "\146\146\145\144\146\146\145\144\146\146\145\144\146\146\145\144"
    "\145\145\145\144\152\252\252\244\152\252\252\244\152\252\252\244"
    "\152\252\252\244\152\252\252\244\152\252\252\244\025\125\125\120" }, 
  { "rtl_logo", NULL, 102, 16, 16, 7, 7, 
    "\125\125\125\125\152\252\252\251\145\125\131\131\144\000\031\031"
    "\145\125\131\031\152\252\251\031\145\145\131\031\144\144\031\031"
    "\144\144\031\031\144\145\131\131\144\152\252\251\144\145\125\131"
    "\144\144\000\031\145\145\125\131\152\252\252\251\125\125\125\125" }, 
  { "sailboat", NULL, 104, 16, 16, 8, 0, 
    "\000\000\120\000\000\000\124\000\000\001\144\000\000\005\145\000"
    "\000\006\151\000\000\026\151\000\000\032\151\100\000\132\152\100"
    "\000\152\152\100\001\152\152\120\001\252\152\220\005\252\152\220"
    "\006\252\152\225\026\252\152\245\132\251\132\200\025\125\124\000" }, 
  { "sb_down_arrow", NULL, 106, 9, 16, 4, 15, 
    "\005\124\001\231\000\146\100\031\220\006\144\001\231\000\146\100"
    "\031\220\006\144\001\231\005\146\125\131\225\052\252\002\252\000"
    "\052\000\002\000" }, 
  { "sb_h_double_arrow", NULL, 108, 17, 18, 9, 9, 
    "\000\005\124\000\000\001\231\000\000\000\146\100\000\000\031\220"
    "\000\000\006\144\000\000\121\231\024\000\144\146\106\100\151\031"
    "\221\244\152\252\152\252\132\252\232\252\221\244\146\106\220\031"
    "\031\221\220\001\106\144\120\000\001\231\000\000\000\146\100\000"
    "\000\031\220\000\000\006\144\000\000\001\125\000\000" }, 
  { "sb_left_arrow", NULL, 110, 16, 9, 0, 4, 
    "\000\120\000\000\001\220\000\000\006\225\125\125\032\252\252\252"
    "\152\225\125\125\032\252\252\252\006\225\125\125\001\220\000\000"
    "\000\120\000\000" }, 
  { "sb_right_arrow", NULL, 112, 16, 9, 15, 4, 
    "\000\000\005\000\000\000\006\100\125\125\126\220\252\252\252\244"
    "\125\125\126\251\252\252\252\244\125\125\126\220\000\000\006\100"
    "\000\000\005\000" }, 
  { "sb_up_arrow", NULL, 114, 9, 16, 4, 0, 
    "\000\200\000\250\000\252\200\252\250\126\145\125\231\120\146\100"
    "\031\220\006\144\001\231\000\146\100\031\220\006\144\001\231\000"
    "\146\100\025\120" },
  { "sb_v_double_arrow", NULL, 116, 18, 17, 9, 9, 
    "\000\000\120\000\000\000\032\100\000\000\006\251\000\000\001\252"
    "\244\000\000\025\245\100\000\000\012\000\000\125\125\245\125\126"
    "\252\252\252\251\125\125\125\125\126\252\252\252\251\125\125\245"
    "\125\120\000\012\000\000\000\025\245\100\000\001\252\244\000\000"
    "\006\251\000\000\000\032\100\000\000\000\120\000\000" }, 
  { "shuttle", NULL, 118, 16, 16, 11, 0, 
    "\000\000\006\100\000\000\032\220\000\000\152\244\000\000\251\252"
    "\000\030\251\252\000\144\251\252\001\224\251\252\001\224\251\252"
    "\001\224\251\252\001\224\251\252\006\224\251\252\032\224\251\252"
    "\152\250\251\252\025\244\145\144\000\120\032\244\000\000\006\220" }, 
  { "sizing", IDC_SIZENWSE, 120, 16, 16, 8, 8, 
    "\125\125\120\000\152\252\220\000\145\125\120\000\144\000\000\000"
    "\144\125\125\000\144\152\251\000\144\145\131\025\144\144\031\031"
    "\144\144\031\031\124\145\131\031\000\152\251\031\000\125\126\131"
    "\000\000\001\231\000\005\125\151\000\006\252\251\000\005\125\125" }, 
  { "spider", NULL, 122, 16, 16, 6, 7, 
    "\030\000\002\100\006\000\011\000\002\000\010\000\001\200\044\000"
    "\100\225\140\001\220\152\220\152\050\152\222\220\006\252\251\000"
    "\006\252\250\000\050\152\226\200\220\152\220\152\100\225\140\001"
    "\001\200\040\000\002\100\030\000\006\000\011\000\030\000\002\100" }, 
  { "spraycan", NULL, 124, 12, 16, 10, 2, 
    "\000\000\012\001\100\205\006\230\112\012\244\205\032\144\112\152"
    "\251\000\145\131\000\152\131\000\146\131\000\152\131\000\146\131"
    "\000\152\131\000\152\131\000\145\131\000\145\131\000\152\251\000" }, 
  { "star", NULL, 126, 16, 16, 7, 7, 
    "\000\002\000\000\000\011\200\000\000\011\200\000\000\030\220\000"
    "\000\044\140\000\000\140\044\000\001\140\045\100\132\202\012\224"
    "\240\000\000\051\132\200\012\224\005\202\011\100\006\011\202\100"
    "\030\044\140\220\030\220\030\220\032\100\006\220\031\000\001\220" }, 
  { "target", NULL, 128, 16, 15, 7, 7, 
    "\000\025\120\000\000\132\224\000\001\252\251\000\006\240\052\100"
    "\032\000\002\220\150\001\000\244\240\006\100\051\240\030\220\051"
    "\240\006\100\051\150\001\000\244\032\000\002\220\006\240\052\100"
    "\001\252\251\000\000\132\224\000\000\025\120\000" }, 
  { "tcross", IDC_CROSS, 130, 15, 15, 7, 7, 
    "\000\005\100\000\000\031\000\000\000\144\000\000\001\220\000\000"
    "\006\100\000\000\031\000\005\125\145\125\132\252\252\251\125\126"
    "\125\124\000\031\000\000\000\144\000\000\001\220\000\000\006\100"
    "\000\000\031\000\000\000\124\000\000" }, 
  { "top_left_arrow", NULL, 132, 16, 16, 1, 1, 
    "\124\000\000\000\151\100\000\000\152\224\000\000\032\251\100\000"
    "\032\252\224\000\006\252\251\120\006\252\252\220\001\252\225\120"
    "\001\252\220\000\000\151\144\000\000\151\031\000\000\031\006\100"
    "\000\031\001\220\000\025\000\144\000\000\000\031\000\000\000\005" }, 
  { "top_left_corner", IDC_SIZENWSE, 134, 16, 16, 1, 1, 
    "\125\125\125\125\152\252\252\251\152\252\252\251\151\125\125\125"
    "\151\000\000\000\151\025\125\120\151\032\252\220\151\032\125\120"
    "\151\031\220\000\151\031\144\000\151\031\031\000\151\031\006\100"
    "\151\031\001\220\151\025\000\120\151\000\000\000\125\000\000\000" }, 
  { "top_right_corner", IDC_SIZENESW, 136, 16, 16, 14, 1, 
    "\125\125\125\125\152\252\252\251\152\252\252\251\125\125\125\151"
    "\000\000\000\151\005\125\124\151\006\252\244\151\005\125\244\151"
    "\000\006\144\151\000\031\144\151\000\144\144\151\001\220\144\151"
    "\006\100\144\151\005\000\124\151\000\000\000\151\000\000\000\125" }, 
  { "top_side", IDC_SIZENS, 138, 15, 16, 7, 1, 
    "\125\125\125\125\252\252\252\226\252\252\252\125\125\125\125\000"
    "\006\100\000\000\152\100\000\006\146\100\000\145\226\100\006\106"
    "\106\100\024\031\005\000\000\144\000\000\001\220\000\000\006\100"
    "\000\000\031\000\000\000\144\000\000\001\120\000" }, 
  { "top_tee", NULL, 140, 16, 12, 8, 1, 
    "\125\125\125\125\152\252\252\251\152\252\252\251\125\126\225\125"
    "\000\006\220\000\000\006\220\000\000\006\220\000\000\006\220\000"
    "\000\006\220\000\000\006\220\000\000\006\220\000\000\005\120\000" }, 
  { "trek", NULL, 142, 9, 16, 4, 0, 
    "\001\220\000\124\000\152\100\152\244\152\252\132\232\226\252\244"
    "\152\244\006\244\004\144\106\152\145\246\151\145\226\131\021\226"
    "\104\145\220\031" }, 
  { "ul_angle", NULL, 144, 12, 12, 1, 1, 
    "\125\125\125\152\252\251\152\252\251\151\125\125\151\000\000\151"
    "\000\000\151\000\000\151\000\000\151\000\000\151\000\000\151\000"
    "\000\125\000\000" }, 
  { "umbrella", NULL, 146, 16, 16, 8, 2, 
    "\001\025\024\124\121\125\125\105\105\225\226\120\025\131\131\225"
    "\145\226\231\140\131\152\245\225\126\006\102\124\000\006\100\000"
    "\000\006\100\000\000\006\100\000\000\006\100\000\000\006\124\000"
    "\000\006\124\000\000\006\144\000\000\006\144\000\000\001\220\000" }, 
  { "ur_angle", NULL, 148, 12, 12, 10, 1, 
    "\125\125\125\152\252\251\152\252\251\125\125\151\000\000\151\000"
    "\000\151\000\000\151\000\000\151\000\000\151\000\000\151\000\000"
    "\151\000\000\125" }, 
  { "watch", IDC_WAIT, 150, 16, 16, 15, 9, 
    "\006\252\251\000\006\252\251\000\006\252\251\000\032\252\252\100"
    "\151\126\126\220\245\126\125\245\225\126\125\152\225\132\225\152"
    "\225\132\225\152\225\145\125\152\245\225\125\245\151\125\126\220"
    "\032\252\252\100\006\252\251\000\006\252\251\000\006\252\251\000" }, 
  { "xterm", IDC_IBEAM, 152, 9, 16, 4, 8, 
    "\125\025\132\232\225\152\124\026\120\001\220\000\144\000\031\000"
    "\006\100\001\220\000\144\000\031\000\006\100\005\224\025\251\126"
    "\246\245\124\125" }, 
  { NULL, NULL, 0, 0, 0, 0, 0, NULL },
};
